Micromet Documentation
================

Welcome to Micromet's documentation!

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   getting_started
   data_processing
   modules
   about_ufn
   ameriflux_variables
   links
   micromet